import { lobbyMessage } from "../Classes/lobbyMessage";
import { playerData } from "../Classes/playerData"
import { playerInventory } from "../Classes/playerInventory";
import { game } from "../game";

export function registerLobbyCallbacks(socket){
    socket.on('lobby/playerJoin', (data) => {
        if(!socket.hasOwnProperty("user")) return;

        let buff = Buffer.from(data, 'base64');
        let data1 : playerData = JSON.parse(buff.toString('utf-8'));

        socket.player.characterId = data1.characterId
        game.lobbyState.addUser(socket.user, socket.player)
        game.socketIO.emit("lobby/playerJoin", JSON.stringify(game.lobbyState))
        game.addMessage(new lobbyMessage(socket.user.login + " joined"))
    });

    socket.on('lobby/playerUpdate', (data) => {
        if(!socket.hasOwnProperty("user")) return;

        let buff = Buffer.from(data, 'base64');
        let data1 : playerData = JSON.parse(buff.toString('utf-8'));

        let player = game.lobbyState.findPlayer(socket.user.id)
        if(player == null){
            console.log("Error! Player not spawned!")
        }
        else{
            player.rigidbody = data1.rigidbody
        }
    });

    socket.on('lobby/lobbyUpdate', (data) => {
        if(!socket.hasOwnProperty("user")) return;

        let buff = Buffer.from(data, 'base64');
        let data1 = JSON.parse(buff.toString('utf-8'));

        game.lobbyState.objects = data1.objects
    });

    socket.on('lobby/loadoutChanged', (data) => {
        if(!socket.hasOwnProperty("user")) return;

        let buff = Buffer.from(data, 'base64');
        let data1 : playerData = JSON.parse(buff.toString('utf-8'));

        let player = game.lobbyState.findPlayer(socket.user.id)
        player.inventory = data1.inventory
        playerInventory.validate(player.inventory)

        game.socketIO.emit("lobby/loadoutChanged", JSON.stringify(player))
    });

    socket.on('lobby/message', (data) => {
        if(!socket.hasOwnProperty("user")) return;

        let buff = Buffer.from(data, 'base64');
        let data1 : lobbyMessage = JSON.parse(buff.toString('utf-8'));
        data1.timestamp = new Date().toLocaleString();

        game.addMessage(data1)
    });
}