import { registerAccountCallbacks } from "./Account/accountSocket";
import { users } from "./Account/users";
import { registerLobbyCallbacks } from "./Lobby/lobbySocket";
import { playerData } from "./Classes/playerData";
import { game } from "./game";
import { registerItemCallbacks } from "./Items/itemSocket";
import { players } from "./Player/players";

const express = require("express");
const app = express();
const port = 3000;
const server = require('http').Server(app);

server.listen(port, () => {
  console.log(`Server listening at port ${port}`);
});

const io = require("socket.io")(server, {
	cors: {
        origin: '*',
        methods: ["GET", "POST"]
    }
});

users.loadUsers();
players.loadPlayers();

io.on('connection', (socket) => {
	console.log("Got connection!");
	socket.emit("connectSuccess", "");

    registerAccountCallbacks(socket);
    registerLobbyCallbacks(socket);
    registerItemCallbacks(socket);
    
    socket.io = game.socketIO = io;

    socket.on("disconnect", () => {
        socket.disconnect()
        if(socket.hasOwnProperty("user")){
            game.lobbyState.removeUser(socket.user.id)
            delete socket.user
        }
        console.log(socket.id + " disconnected");
    });

    socket.on('error',function(er){
        console.log(er);
    });
});

//Send player updates to everyone
setInterval(() => {
    let userCount = game.lobbyState.players.length
    if(userCount > 0){
        game.lobbyState.hostId = game.lobbyState.users[0].id
        io.emit('lobby', JSON.stringify(game.lobbyState.copyLight()))
    }
}, 1000/30)

setInterval(() => {
    console.log("Players: " + game.lobbyState.players.length + ", users: " + game.lobbyState.users.length);
}, 60 * 1000)

process.on('SIGINT', function () {
    console.log('Ctrl-C...');
    process.exit(2);
});
process.on('exit', function () {
    users.saveUsers();
    players.savePlayers();
    console.log("exitted");
});